using System;
using Server;
using Server.Mobiles;

namespace Server.Items
{
	public class RedSolenEggSack : Item, ICarvable
	{
		private RedSpawnTimer m_Timer;

		[Constructable]
		public RedSolenEggSack() : base( 0x10D9 )
		{
			Movable = false;		
			m_Timer = new RedSpawnTimer( this );
			m_Timer.Start();
		}

		public void Carve( Mobile from, Item item )
		{
			from.SendMessage( "You destroy the egg sack." );

			Delete();

			m_Timer.Stop();
		}

		public RedSolenEggSack( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );

			writer.Write( (int) 0 ); // version
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );

			int version = reader.ReadInt();

			m_Timer = new RedSpawnTimer( this );
			m_Timer.Start();
		}

		private class RedSpawnTimer : Timer
		{
			private Item m_Item;

			public RedSpawnTimer( Item item ) : base( TimeSpan.FromSeconds( 2.5 + (Utility.RandomDouble() * 2.5) ) )
			{
				Priority = TimerPriority.FiftyMS;
				m_Item = item;
			}

			protected override void OnTick()
			{
				if ( m_Item.Deleted )
					return;

				Mobile spawn;

			 	switch ( Utility.Random( 2 ) )
				{
					default:
					case 0: spawn = new RedSolenWarrior(); break;
					case 1: spawn = new RedSolenWorker(); break;
				
				}
				spawn.Map = m_Item.Map;
				spawn.Location = m_Item.Location;

				m_Item.Delete();
			}
		}
	}
	public class BlackSolenEggSack : Item, ICarvable
	{
		private BlackSpawnTimer m_Timer;

		[Constructable]
		public BlackSolenEggSack() : base( 0x10D9 )
		{
			Movable = false;		
			m_Timer = new BlackSpawnTimer( this );
			m_Timer.Start();
		}

		public void Carve( Mobile from, Item item )
		{
			from.SendMessage( "You destroy the egg sack." );

			Delete();

			m_Timer.Stop();
		}

		public BlackSolenEggSack( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );

			writer.Write( (int) 0 ); // version
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );

			int version = reader.ReadInt();

			m_Timer = new BlackSpawnTimer( this );
			m_Timer.Start();
		}

		private class BlackSpawnTimer : Timer
		{
			private Item m_Item;

			public BlackSpawnTimer( Item item ) : base( TimeSpan.FromSeconds( 2.5 + (Utility.RandomDouble() * 2.5) ) )
			{
				Priority = TimerPriority.FiftyMS;
				m_Item = item;
			}

			protected override void OnTick()
			{
				if ( m_Item.Deleted )
					return;

				Mobile spawn;

				switch ( Utility.Random( 2 ) )
				{
					default:
					case 0: spawn = new BlackSolenWarrior(); break;
					case 1: spawn = new BlackSolenWorker(); break;
				
				}
				spawn.Map = m_Item.Map;
				spawn.Location = m_Item.Location;

				m_Item.Delete();
			}
		}
	}
}
