using System;
using System.Collections;
using Server.Items;
using Server.Targeting;
using Server.ContextMenus;
using Server.Gumps;
using Server.Misc;

namespace Server.Mobiles
{
	[CorpseName( "a solen queen corpse" )]
	public class RedAmbitiousQueen : BaseCreature
	{
		[Constructable]
		public RedAmbitiousQueen() : base(AIType.AI_Thief, FightMode.None, 10, 1, 0.8, 2.6 )
		{
			Name = "Ambitious Queen";
			Body = 807;
			BaseSoundID = 959;
			Blessed = true;
			SetStr( 296, 320 );
			SetDex( 121, 145 );
			SetInt( 76, 100 );

			SetHits( 151, 162 );

			SetDamage( 10, 15 );

			SetDamageType( ResistanceType.Physical, 70 );
			SetDamageType( ResistanceType.Poison, 30 );

			SetResistance( ResistanceType.Physical, 30, 40 );
			SetResistance( ResistanceType.Fire, 30, 35 );
			SetResistance( ResistanceType.Cold, 25, 35 );
			SetResistance( ResistanceType.Poison, 35, 40 );
			SetResistance( ResistanceType.Energy, 25, 30 );

			SetSkill( SkillName.MagicResist, 70.0 );
			SetSkill( SkillName.Tactics, 90.0 );
			SetSkill( SkillName.Wrestling, 90.0 );

			Fame = 4500;
			Karma = -4500;

			VirtualArmor = 45;

		}

		public RedAmbitiousQueen( Serial serial ) : base( serial )
		{
		}

		public override void GetContextMenuEntries( Mobile from, ArrayList list ) 
		{ 
			base.GetContextMenuEntries( from, list ); 
			list.Add( new AmbitiousQueenEntry( from ) ); 
		}

		public class AmbitiousQueenEntry : ContextMenuEntry
		{
			private Mobile m_Mobile;

			public AmbitiousQueenEntry( Mobile from ) : base( 6146, 3 )
			{
				m_Mobile = from;
			}
          
			public override void OnClick()
			{
				if( !( m_Mobile is PlayerMobile ) )
					return;

				PlayerMobile mobile = (PlayerMobile) m_Mobile;
				BaseQuest quest = mobile.CurrentQuest;

				if( mobile.CurrentQuest == null )
				{
					if( mobile.CanStartNewQuest )
					{
						if ( !mobile.HasGump( typeof( OfferQuestGump ) ) )
						{
							mobile.CurrentQuest = new RedAmbitiousQueenQuest1( mobile );
							mobile.SendGump( new OfferQuestGump( mobile.CurrentQuest ) );
						}
					}
					else
					{
						mobile.SendGump( new RestingQuestGump() );
					}
				}		
				else if( mobile.CurrentQuest is RedAmbitiousQueenQuest1 )
				{
					if( quest.Completed )
					{
						mobile.PlaySound( 602 );
						mobile.SendGump( new FinishQuestGump( quest ) );
						mobile.CurrentQuest = new RedAmbitiousQueenQuest2( mobile );
						mobile.SendGump( new QuestLogUpdated() );
						
					}
					else
					{
						mobile.PlaySound( 599 );
						mobile.SendGump( new QuestInProgressGump( mobile.CurrentQuest ) );
					}						
				}
				else if( quest is RedAmbitiousQueenQuest2 )
				{
						mobile.PlaySound( 599 );
						mobile.SendGump( new QuestInProgressGump( mobile.CurrentQuest ) );
				}
				else
				{
					mobile.PlaySound( 599 );
					mobile.SendGump( new OccupiedQuestGump( 1054059 ) );
				}		
			}
		}
		

		public override bool OnDragDrop( Mobile from, Item dropped )
		{
			Mobile m = from; 
			PlayerMobile mobile = m as PlayerMobile;
			BaseQuest quest = mobile.CurrentQuest;
 
			if( mobile != null )
			{
				if( dropped is ZoogiFungus )
				{
					if( quest is RedAmbitiousQueenQuest2 )
					{        	
						if(dropped.Amount==50)
						{
							Bag bag = new Bag();
							bag.Hue = 347;
							bag.DropItem( new TranslocationPowder(25) );
							bag.DropItem( new Gold(1000) );
							bag.DropItem( new BagofSending() );
							
							if( quest.CanRecieveItem( mobile, bag ) )
							{
								dropped.Delete();
								mobile.SendLocalizedMessage(1054074);
								mobile.SendLocalizedMessage(1054075);
								mobile.SendLocalizedMessage(1054076);
								mobile.PlaySound( 602 );
								mobile.SendGump( new FinishQuestGump( quest ) );
								return true;
							}
							else
							{
								mobile.SendGump( new OverLoadedGump( quest ) );
								return false;
							}
						}
						else
						{
							mobile.PlaySound( 599 );
							this.Say( 1054072 );
							return false;
						}
					}
					else
					{
						mobile.PlaySound( 599 );
						this.Say( 1054071 );
						return false;
					}
				}
				return false;
			}
			return false;
		}

		public override int GetAngerSound()
		{
			return 0x259;
		}

		public override int GetIdleSound()
		{
			return 0x259;
		}

		public override int GetAttackSound()
		{
			return 0x195;
		}

		public override int GetHurtSound()
		{
			return 0x250;
		}

		public override int GetDeathSound()
		{
			return 0x25B;
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
		}
	}
}
