using System;
using System.Collections;
using Server.Items;
using Server.Mobiles;
using Server.Misc;
using Server.Targeting;
using Server.Gumps;

namespace Server.Mobiles
{
	[CorpseName( "a solen queen corpse" )]
	public class RedSolenQueen : BaseCreature
	{
		private Timer BurnTimer;
		public int MaxHits;
		public bool Sacked;
		
		[Constructable]
		public RedSolenQueen() : base( AIType.AI_Melee, FightMode.Closest, 10, 1, 0.2, 0.4 )
		{
			Name = "a red solen queen";
			Body = 783;
			BaseSoundID = 959;
			Sacked = true;
			SetStr( 296, 320 );
			SetDex( 121, 145 );
			SetInt( 76, 100 );

			SetHits( 151, 162 );

			SetDamage( 10, 15 );

			SetDamageType( ResistanceType.Physical, 70 );
			SetDamageType( ResistanceType.Poison, 30 );

			SetResistance( ResistanceType.Physical, 30, 40 );
			SetResistance( ResistanceType.Fire, 30, 35 );
			SetResistance( ResistanceType.Cold, 25, 35 );
			SetResistance( ResistanceType.Poison, 35, 40 );
			SetResistance( ResistanceType.Energy, 25, 30 );

			SetSkill( SkillName.MagicResist, 100.0, 120.0);
			SetSkill( SkillName.Tactics, 90.0 );
			SetSkill( SkillName.Wrestling, 90.0 );

			Fame = 4500;
			Karma = -4500;

			VirtualArmor = 45;

			SolenHelper.PackPicnicBasket( this );

			int zoogicount = Utility.RandomMinMax( 5, 25 );
			ZoogiFungus zoogi= new ZoogiFungus();
			zoogi.Amount=zoogicount;
			PackItem(zoogi);

			if ( 0.02 > Utility.RandomDouble() )
				PackItem( new PetSummonBall() );
		}
		
		public override void GenerateLoot()
		{
			AddLoot( LootPack.AosRich, 1 );
		}		
			
		public override bool IsEnemy( Mobile m )
		{
			PlayerMobile mobile = m as PlayerMobile; 
			
			if ( m is BlackSolenWorker || m is BlackSolenQueen || m is BlackSolenWarrior || m is BlackSolenInfiltratorQueen || m is BlackSolenInfiltratorWarrior )
				return true;
		
			if ( mobile != null )
			{
				if( mobile.SolenFriendship == SolenFriend.Red )
					return false;
			}
			return base.IsEnemy( m );
		}

		public override int GetAngerSound()
		{
			return 0x259;
		}

		public override int GetIdleSound()
		{
			return 0x259;
		}

		public override int GetAttackSound()
		{
			return 0x195;
		}

		public override int GetHurtSound()
		{
			return 0x250;
		}

		public override int GetDeathSound()
		{
			return 0x25B;
		}

		public RedSolenQueen( Serial serial ) : base( serial )
		{
			this.MaxHits=this.HitsMax;
		}
		 
		private DateTime m_NextFirebreath;
	
		public override void OnDamage( int amount, Mobile attacker, bool willKill )
		{		
			if ( attacker != null && !willKill && amount > 5 && 50 > Utility.Random( 100 ) )
			{
				AddSolenEggSack( attacker, 0.50 );
		
				if ( this.Hits < (this.HitsMax/3) && this.Sacked )
				{
					attacker.SendMessage("The Solen's acid sack bursts open!");
					AcidPool acid = new AcidPool(attacker); 
					acid.Map = attacker.Map; 
					acid.Location = attacker.Location; 
					attacker.PlaySound( 0x25 );
				}
				else if ( !this.Sacked )
				{
					attacker.SendMessage("Acid spills from the damaged sack!");
					AcidPool acid = new AcidPool(attacker); 
					acid.Map = attacker.Map; 
					acid.Location = attacker.Location; 
					attacker.PlaySound( 0x25 );
				}
				BurnTimer = new m_Timer( attacker );
				BurnTimer.Start();
			}
			if( attacker is PlayerMobile )
			{
				PlayerMobile mobile = attacker as PlayerMobile;

				if( mobile.SolenFriendship == SolenFriend.Red )
				{
					mobile.SolenFriendship = SolenFriend.None;
					mobile.SendLocalizedMessage( 1054103 );
				}
			}

			base.OnDamage( amount, attacker, willKill );
		}
		 
		public override void OnActionCombat() 
		{ 
         
			Mobile combatant = Combatant; 

			if ( !Sacked || combatant == null || combatant.Deleted || combatant.Map != Map || !InRange( combatant, 12 ) || !CanBeHarmful( combatant ) || !InLOS( combatant ) ) 
				return; 
			if ( DateTime.Now > m_NextFirebreath ) 
			{ 
				m_NextFirebreath = DateTime.Now + TimeSpan.FromSeconds( Utility.Random( 5, 15 ) ); // 5-15 seconds 
				this.GetDirectionTo( combatant.Location ); //check direction 
				this.Freeze( TimeSpan.FromSeconds( 2 ) ); //freeze for animation 
				this.Animate( 12, 5, 1, true, false, 0 ); //animation 
				this.PlaySound( GetAngerSound() ); // Sound 
				new InternalTimer( this, combatant, (int)this.Hits ).Start(); // start timer with saved current hits value
				BurnTimer = new m_Timer( combatant );
				BurnTimer.Start();
			} 
		} 
        
		private class InternalTimer : Timer 
		{ 
			private Mobile m_Mobile; 
			private Mobile a_Mobile; 
			private int m_hits; 

			public InternalTimer( Mobile mobile, Mobile attacker, int hits ) : base( TimeSpan.FromSeconds( 1.5 ) ) 
			{ 
				Priority = TimerPriority.FiftyMS; 
				m_Mobile = mobile;
				a_Mobile = attacker;
			} 

			protected override void OnTick() 
			{ 
				RedSolenQueen queen = m_Mobile as RedSolenQueen; 
                  	
				if ( queen != null )
				{
					if ( a_Mobile != null && a_Mobile.Alive ) 
					{ 
						int damage = Utility.Random( 26,30 );
						queen.DoHarmful( a_Mobile ); 
						AOS.Damage( a_Mobile, queen, damage, 50, 0, 0, 50, 0 ); //Fire damage 100% 
						queen.MovingEffect( a_Mobile, 0x36D4, 7, 0, false, false, 0x73, 1 );
						AcidPool acid = new AcidPool(a_Mobile); 
						acid.Map = a_Mobile.Map; 
						acid.Location = a_Mobile.Location; 
						a_Mobile.PlaySound( 0x25 );
                      	
						if ( a_Mobile.Alive && a_Mobile.Body.IsHuman && !a_Mobile.Mounted ) 
						{ 
							a_Mobile.Animate( 20, 7, 1, true, false, 0 ); // take hit 
						} 
						Stop(); 
					}
				}
			}
		}
           
		public override void OnMovement(Mobile m, Point3D oldLocation ) 
		{
			if ( BurnTimer != null )
				BurnTimer.Stop();

			BurnTimer = null;
		}

		public override void OnAfterDelete()
		{
			if ( BurnTimer != null )
				BurnTimer.Stop();

			BurnTimer = null;

			base.OnAfterDelete();
		}
			
		private class m_Timer: Timer
		{
			private Mobile m_Mobile;

			public m_Timer( Mobile from ) : base( TimeSpan.FromSeconds( 1.0 ),TimeSpan.FromSeconds( 1.0 ) )
			{
				Priority = TimerPriority.FiftyMS;
				m_Mobile = from;
			}

			protected override void OnTick()
			{
				ArrayList list = new ArrayList();

				foreach ( Item m in m_Mobile.GetItemsInRange( 10 ) )
				{
					if( m is AcidPool )
					{
						list.Add(m);
					}
				}
				if( list.Count > 0 && m_Mobile.Alive )
				{
					m_Mobile.Damage( Utility.Random( 5 ) );
					m_Mobile.PlaySound(0x1dE);
				}
				else
					Stop();
			}
		}
	
		public void AddSolenEggSack( Mobile target, double chanceToThrow )
		{
			if ( chanceToThrow >= Utility.RandomDouble() )
			{
				Direction = GetDirectionTo( target );
				MovingEffect( target, 0xF7E, 10, 1, true, false, 0x496, 0 );
				new DelayTimer( this, target ).Start();
			}
			else
			{
				new RedSolenEggSack().MoveToWorld( Location, Map );
			}
		}

		private class DelayTimer : Timer
		{
			private Mobile m_Mobile;
			private Mobile m_Target;

			public DelayTimer( Mobile m, Mobile target ) : base( TimeSpan.FromSeconds( 1.0 ) )
			{
				m_Mobile = m;
				m_Target = target;
			}

			protected override void OnTick()
			{
				if ( m_Mobile.CanBeHarmful( m_Target ) )
				{
					m_Mobile.DoHarmful( m_Target );
					AOS.Damage( m_Target, m_Mobile, Utility.RandomMinMax( 10, 20 ), 100, 0, 0, 0, 0 );
					new RedSolenEggSack().MoveToWorld( m_Target.Location, m_Target.Map );
				}
			}
		}
		
		public void GiveKillCount()
		{
			ArrayList toGive = new ArrayList();

			ArrayList list = Aggressors;
			for ( int i = 0; i < list.Count; ++i )
			{
				AggressorInfo info = (AggressorInfo)list[i];

				if ( info.Attacker.Player &&  (DateTime.Now - info.LastCombatTime) < TimeSpan.FromSeconds( 30.0 ) && !toGive.Contains( info.Attacker ) )
					toGive.Add( info.Attacker );
			}

			list = Aggressed;
			for ( int i = 0; i < list.Count; ++i )
			{
				AggressorInfo info = (AggressorInfo)list[i];

				if ( info.Defender.Player &&  (DateTime.Now - info.LastCombatTime) < TimeSpan.FromSeconds( 30.0 ) && !toGive.Contains( info.Defender ) )
					toGive.Add( info.Defender );
			}

			if ( toGive.Count == 0 )
				return;

			for ( int i = 0; i < toGive.Count; ++i )
			{
				Mobile m = (Mobile)toGive[i % toGive.Count];

				if( !(m is PlayerMobile) )
					return;

				PlayerMobile mobile = m as PlayerMobile;

				if( mobile.CurrentQuest == null )
					return;

				BaseQuest quest = mobile.CurrentQuest;
				int m_Number = quest.CompletedObjectives;
			
				if ( mobile != null ) 
				{ 
					if ( quest is RedAmbitiousQueenQuest1 )
					{
						if( m_Number == 5 )
							return;

						( (QuestObjective) quest.Objectives[ m_Number ] ).Completed = true;
						
						if( quest.Completed )
						{
							mobile.SendGump( new QuestLogUpdated() );
						}
					}
					return;
				}
				return;
			}
		}

		public override bool OnBeforeDeath()
		{
			if ( !NoKillAwards )
			{
				GiveKillCount();
			}
				
			return base.OnBeforeDeath();
		}
		
		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
		}
	}
}
