using System;
using System.Collections;
using Server.Mobiles;
using Server.Items;
using Server.Targeting;

namespace Server.Mobiles
{
	[CorpseName( "a solen warrior corpse" )]
	public class RedSolenWarrior : BaseCreature
	{
		private Timer BurnTimer;
		public int MaxHits;
		public bool Sacked;
		
		[Constructable]
		public RedSolenWarrior() : base( AIType.AI_Melee, FightMode.Closest, 10, 1, 0.2, 0.4 )
		{
			Name = "a red solen warrior";
			Body = 782;
			BaseSoundID = 959;
			Sacked = true;
			SetStr( 196, 220 );
			SetDex( 101, 125 );
			SetInt( 36, 60 );

			SetHits( 96, 107 );

			SetDamage( 5, 15 );

			SetDamageType( ResistanceType.Physical, 80 );
			SetDamageType( ResistanceType.Poison, 20 );

			SetResistance( ResistanceType.Physical, 20, 35 );
			SetResistance( ResistanceType.Fire, 20, 35 );
			SetResistance( ResistanceType.Cold, 10, 25 );
			SetResistance( ResistanceType.Poison, 20, 35 );
			SetResistance( ResistanceType.Energy, 10, 25 );

			SetSkill( SkillName.MagicResist, 100.0, 120.0 );
			SetSkill( SkillName.Tactics, 80.0 );
			SetSkill( SkillName.Wrestling, 80.0 );

			Fame = 3000;
			Karma = -3000;

			VirtualArmor = 35;

			int gems = Utility.RandomMinMax( 1, 4 );

			for ( int i = 0; i < gems; ++i )
				PackGem();

			SolenHelper.PackPicnicBasket( this );

			int zoogicount = Utility.RandomMinMax( 1, 3 );
			ZoogiFungus zoogi= new ZoogiFungus();
			zoogi.Amount=zoogicount;
			PackItem( zoogi );
			
			if ( 0.02 > Utility.RandomDouble() )
				PackItem( new BraceletOfBinding() );
		}
		
		public override void GenerateLoot()
		{
			AddLoot( LootPack.AosAverage, 1 );
		}		
		
		public override bool IsEnemy( Mobile m )
		{
			PlayerMobile mobile = m as PlayerMobile; 
			
			if ( m is BlackSolenWorker || m is BlackSolenQueen || m is BlackSolenWarrior || m is BlackSolenInfiltratorQueen || m is BlackSolenInfiltratorWarrior )
				return true;
		
			if ( mobile != null )
			{
				if( mobile.SolenFriendship == SolenFriend.Red )
					return false;
			}
			return base.IsEnemy( m );
		}

		public RedSolenWarrior( Serial serial ) : base( serial )
		{
			this.MaxHits=this.HitsMax;
		}
		 
		private DateTime m_NextFirebreath;
	
		public override void OnDamage( int amount, Mobile attacker, bool willKill )
		{	
			if ( attacker != null && !willKill && amount > 5 && 50 > Utility.Random( 100 ) )
			{		
				if ( this.Hits < (this.HitsMax/3) && this.Sacked )
				{
					attacker.SendMessage("The Solen's acid sack bursts open!");
					AcidPool acid = new AcidPool(attacker); 
					acid.Map = attacker.Map; 
					acid.Location = attacker.Location; 
					attacker.PlaySound( 0x25 );
				}
				else if ( !this.Sacked )
				{
					attacker.SendMessage("Acid spills from the damaged sack!");
					AcidPool acid = new AcidPool(attacker); 
					acid.Map = attacker.Map; 
					acid.Location = attacker.Location; 
					attacker.PlaySound( 0x25 );
				}
				BurnTimer = new m_Timer( attacker );
				BurnTimer.Start();
			}
			if( attacker is PlayerMobile )
			{
				PlayerMobile mobile = attacker as PlayerMobile;

				if( mobile.SolenFriendship == SolenFriend.Red )
				{
					mobile.SolenFriendship = SolenFriend.None;
					mobile.SendLocalizedMessage( 1054103 );
				}
			}
			base.OnDamage( amount, attacker, willKill );
		}

		public override void OnActionCombat() 
		{ 
         
			Mobile combatant = Combatant; 

			if ( !Sacked || combatant == null || combatant.Deleted || combatant.Map != Map || !InRange( combatant, 12 ) || !CanBeHarmful( combatant ) || !InLOS( combatant ) ) 
				return; 
			if ( DateTime.Now > m_NextFirebreath ) 
			{ 
				m_NextFirebreath = DateTime.Now + TimeSpan.FromSeconds( Utility.Random( 5, 15 ) ); // 5-15 seconds 
				this.GetDirectionTo( combatant.Location ); //check direction 
				this.Freeze( TimeSpan.FromSeconds( 2 ) ); //freeze for animation 
				this.Animate( 12, 5, 1, true, false, 0 ); //animation 
				this.PlaySound( GetAngerSound() ); // Sound 
				new InternalTimer( this, combatant, (int)this.Hits ).Start(); // start timer with saved current hits value 
				BurnTimer = new m_Timer( combatant );
				BurnTimer.Start();
			} 
		}
  
		private class InternalTimer : Timer 
		{ 
			private Mobile m_Mobile; 
			private Mobile a_Mobile; 
			private int m_hits; 

			public InternalTimer( Mobile mobile, Mobile attacker, int hits ) : base( TimeSpan.FromSeconds( 1.5 ) ) 
			{ 
				Priority = TimerPriority.FiftyMS; 
				m_Mobile = mobile;
				a_Mobile = attacker;
			} 

			protected override void OnTick() 
			{ 
				RedSolenWarrior warrior = m_Mobile as RedSolenWarrior; 
                  	
				if ( warrior != null )
				{
					if ( a_Mobile != null && a_Mobile.Alive ) 
					{ 
						int damage = Utility.Random( 26,30 );
						warrior.DoHarmful( a_Mobile ); 
						AOS.Damage( a_Mobile, warrior, damage, 50, 0, 0, 50, 0 ); //Fire damage 100% 
						warrior.MovingEffect( a_Mobile, 0x36D4, 7, 0, false, false, 0x73, 1 );
						AcidPool acid = new AcidPool(a_Mobile); 
						acid.Map = a_Mobile.Map; 
						acid.Location = a_Mobile.Location; 
						a_Mobile.PlaySound( 0x25 );
                      	
						if ( a_Mobile.Alive && a_Mobile.Body.IsHuman && !a_Mobile.Mounted ) 
						{ 
							a_Mobile.Animate( 20, 7, 1, true, false, 0 ); // take hit 
						} 
						Stop(); 
					}
				}
			}
		}
           
		public override void OnMovement(Mobile m, Point3D oldLocation ) 
		{
			if ( BurnTimer != null )
				BurnTimer.Stop();

			BurnTimer = null;
		}

		public override void OnAfterDelete()
		{
			if ( BurnTimer != null )
				BurnTimer.Stop();

			BurnTimer = null;

			base.OnAfterDelete();
		}
			
		private class m_Timer: Timer
		{
			private Mobile m_Mobile;

			public m_Timer( Mobile from ) : base( TimeSpan.FromSeconds( 1.0),TimeSpan.FromSeconds( 1.0 ) )
			{
				Priority = TimerPriority.FiftyMS;
				m_Mobile = from;
			}

			protected override void OnTick()
			{
				ArrayList list = new ArrayList();

				foreach ( Item m in m_Mobile.GetItemsInRange( 10 ) )
				{
					if( m is AcidPool )
					{
						list.Add(m);
					}
				}
				if( list.Count > 0 && m_Mobile.Alive )
				{
					m_Mobile.Damage( Utility.Random( 5 ) );
					m_Mobile.PlaySound(0x1dE);
				}
				else
					Stop();
			}
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
		}
	}
}
