using System;
using System.Collections;
using Server.Items;
using Server.Targeting;

namespace Server.Mobiles
{
	[CorpseName( "a solen worker corpse" )]
	public class RedSolenWorker : BaseCreature
	{
		[Constructable]
		public RedSolenWorker() : base( AIType.AI_Melee, FightMode.Closest, 10, 1, 0.2, 0.4 )
		{
			Name = "a red solen worker";
			Body = 781;
			BaseSoundID = 959;

			SetStr( 96, 120 );
			SetDex( 81, 105 );
			SetInt( 36, 60 );

			SetHits( 58, 72 );

			SetDamage( 5, 7 );

			SetDamageType( ResistanceType.Physical, 100 );

			SetResistance( ResistanceType.Physical, 25, 30 );
			SetResistance( ResistanceType.Fire, 20, 30 );
			SetResistance( ResistanceType.Cold, 10, 20 );
			SetResistance( ResistanceType.Poison, 10, 20 );
			SetResistance( ResistanceType.Energy, 20, 30 );

			SetSkill( SkillName.MagicResist, 60.0 );
			SetSkill( SkillName.Tactics, 65.0 );
			SetSkill( SkillName.Wrestling, 60.0 );

			Fame = 1500;
			Karma = -1500;

			VirtualArmor = 28;
			
			SolenHelper.PackPicnicBasket( this );

			int zoogicount = Utility.RandomMinMax( 1, 6 );
			ZoogiFungus zoogi= new ZoogiFungus();
			zoogi.Amount=zoogicount;
			PackItem( zoogi );
		}
		
		public override void GenerateLoot()
		{
			AddLoot( LootPack.AosMeager, 1 );
		}		
			
		public override bool IsEnemy( Mobile m )
		{
			PlayerMobile mobile = m as PlayerMobile; 
			
			if ( m is BlackSolenWorker || m is BlackSolenQueen || m is BlackSolenWarrior || m is BlackSolenInfiltratorQueen || m is BlackSolenInfiltratorWarrior )
				return true;
		
			if ( mobile != null )
			{
				if( mobile.SolenFriendship == SolenFriend.Red )
					return false;
			}
			return base.IsEnemy( m );
		}

		public override void OnDamage( int amount, Mobile attacker, bool willKill )
		{
			if( attacker is PlayerMobile )
			{
				PlayerMobile mobile = attacker as PlayerMobile;

				if( mobile.SolenFriendship == SolenFriend.Red )
				{
					mobile.SolenFriendship = SolenFriend.None;
					mobile.SendLocalizedMessage( 1054103 );
				}
			}
			base.OnDamage( amount, attacker, willKill );
		}

		public override int GetAngerSound()
		{
			return 0x269;
		}

		public override int GetIdleSound()
		{
			return 0x269;
		}

		public override int GetAttackSound()
		{
			return 0x186;
		}

		public override int GetHurtSound()
		{
			return 0x1BE;
		}

		public override int GetDeathSound()
		{
			return 0x8E;
		}

		public RedSolenWorker( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
		}
	}
}
