using System;
using System.Collections;
using Server.Items;
using Server.Network;
using Server.Mobiles;
using Server.Misc;

namespace Server.Gumps
{
	public class QuestGump
	{
		private QuestGump()
		{
		}

		public static int LocalizedWhite	= 0x7fff;

		// Used for localized HTML and labels.
		public static int LocalizedGreen	= 0x03e8;
		public static int LocalizedYellow	= 0x77ab;
		public static int LocalizedBlue		= 0x125b;
		public static int LocalizedRed		= 0x7827;
		
		// Used for non-localized HTML.
		public static string HtmlGreen		= "00FF42";
		public static string HtmlYellow		= "EFEF5A";
		public static string HtmlBlue		= "2196DE";
		public static string HtmlRed		= "F70839";
		
		public static string Color( string text, string color ) 
		{ 
			return String.Format( "<BASEFONT COLOR=#{0}>{1}</BASEFONT>", color, text ); 
		}
	}
	public class QuestLogGump : Gump
	{
		private BaseQuest m_Quest; 

		public QuestLogGump( BaseQuest quest ) : base( 10, 10 )
		{
			m_Quest = quest;

			Closable = false;
			Dragable = true;

			AddPage(0);
			AddImageTiled(  38, 43, 389, 381, 2624 );
			AddAlphaRegion( 38, 43, 389, 381 );

			AddImage( 34, 414, 3606);
			AddImageTiled( 34, 45, 14, 370, 3605);
			AddImage( 34, 31, 3602);
			AddImageTiled( 45, 30, 383, 14, 3601);
			AddImageTiled( 48, 414, 375, 15, 3607);
			AddImage( 420, 414, 3608);
			AddImageTiled( 421, 42, 13, 373, 3605);
			AddImage( 421, 30, 3602);
			AddImage( 52, 117, 1231);
			AddImage( 47, 44, 10450);
			AddImage( 383, 44, 10450);
			AddImage( 383, 364, 10450);
			AddImage( 47, 364, 10450);
			AddImage( 114, 59, 9781);
			AddImageTiled( 109, 95, 249, 4, 9307);
			AddHtmlLocalized(154, 62, 200, 30, 1046026, QuestGump.LocalizedWhite , false , false ); // Quest Log
			AddImage( 105, 142, 1210);
			AddHtmlLocalized(124, 139, 200, 30, 1049073, QuestGump.LocalizedWhite , false , false ); // Objective:
			AddImageTiled( 106, 160, 138, 1, 9740);
			AddImageTiled( 108, 279, 138, 1, 9740);
			AddImage( 105, 261, 1210);
			AddHtmlLocalized(124, 258, 200, 30, 1049076, QuestGump.LocalizedWhite , false , false ); // Progress Details:

			if( quest.LogObjectiveNumber > 0 )
				AddHtmlLocalized( 106, 292, 200, 30, quest.LogObjectiveNumber, QuestGump.LocalizedBlue , false , false );
			else
				AddHtml( 106, 292, 200, 30, QuestGump.Color( quest.LogObjectiveString, QuestGump.HtmlBlue ), false , false );
			
			AddButton( 210, 385, 2130, 2129, 1, GumpButtonType.Reply, 0 );

			AddPage(1);
	
			if( quest.TotalObjectives != 0 )
			{
				AddLabel( 106, 311, 293, String.Format( "{0}", quest.CompletedObjectives ) );
				AddLabel( 128, 311, 293, String.Format( " /   {0}", quest.TotalObjectives ) );
			}

			if( !quest.Completed )
			{
				if( quest.LogStartObjectiveNumber > 0 )
					AddHtmlLocalized( 106, 168, 310, 83, quest.LogStartObjectiveNumber, QuestGump.LocalizedBlue, false, false );
				else
					AddHtml( 106, 168, 310, 83, QuestGump.Color( quest.LogStartObjectiveString, QuestGump.HtmlBlue ), false, false );
			}
			else
			{
				AddButton( 88, 383, 9909, 9911, 0, GumpButtonType.Page, 2 );
				AddHtmlLocalized( 113, 385, 70, 17, 1043354, QuestGump.LocalizedWhite, false, false); // Previous

				if( quest.LogFinishObjectiveNumber > 0 )
					AddHtmlLocalized( 106, 168, 310, 83, quest.LogFinishObjectiveNumber, QuestGump.LocalizedBlue, false, false );
				else
					AddHtml( 106, 168, 310, 83, QuestGump.Color( quest.LogFinishObjectiveString, QuestGump.HtmlBlue ), false, false );
			}

			AddPage(2);

			AddHtmlLocalized( 106, 311, 300, 30,  1049077 ,QuestGump.LocalizedBlue, false, false ); //  This objective has been completed.
			AddButton( 355, 383, 9903, 9905, 0, GumpButtonType.Page, 1 );
			AddHtmlLocalized( 320, 385, 70, 17, 1043353, QuestGump.LocalizedWhite, false, false); // Next

			if( quest.LogStartObjectiveNumber > 0 )
				AddHtmlLocalized( 106, 168, 310, 83, quest.LogStartObjectiveNumber, QuestGump.LocalizedBlue, false, false );
			else
				AddHtml( 106, 168, 310, 83, QuestGump.Color( quest.LogStartObjectiveString, QuestGump.HtmlBlue ), false, false );
		}
	}

	public class OfferQuestGump : Gump
	{
		private BaseQuest m_Quest;
		
		public OfferQuestGump( BaseQuest quest ) : base( 10, 10 )
		{
			m_Quest = quest;

			Closable = false;
			Dragable = true;

			AddPage( 0 );
			AddImageTiled(  54, 33, 369, 400, 2624 );
			AddAlphaRegion( 54, 33, 369, 400 );

			AddImageTiled( 416, 39, 44, 389, 203 );

			AddButton( 338, 392, 2130, 2129, 3, GumpButtonType.Reply, 0 );

			AddImage( 97, 49, 9005 );
			AddRadio( 101, 355, 9721, 9724, true, 1 );
			AddRadio( 101, 389, 9721, 9724, false, 2 );
			AddImageTiled( 58, 39, 29, 390, 10460 );
			AddImageTiled( 412, 37, 31, 389, 10460 );
			AddImage( 430, 9, 10441);
			AddImageTiled( 40, 38, 17, 391, 9263 );
			AddImage( 6, 25, 10421 );
			AddImage( 34, 12, 10420 );
			AddImageTiled( 94, 25, 342, 15, 10304 );
			AddImageTiled( 40, 427, 415, 16, 10304 );
			AddImage( -10, 314, 10402 );
			AddImage( 56, 150, 10411 );
			AddImage( 156, 136, 2103 );
			AddImage( 136, 84, 96 );
			AddHtmlLocalized( 139, 59, 200, 30, 1046013, QuestGump.LocalizedWhite, false , false ); // Quest Offer

			if( quest.QuestNameNumber > 0 )
				AddHtmlLocalized( 174, 131, 200, 30, quest.QuestNameNumber, QuestGump.LocalizedGreen, false, false );
			else
				AddHtml( 174, 131, 200, 30, QuestGump.Color( quest.QuestNameString, QuestGump.HtmlGreen ), false, false );

			AddHtmlLocalized(137, 359, 200, 30, 1049011, QuestGump.LocalizedWhite , false , false ); // I accept!
			AddHtmlLocalized(137, 393, 200, 30, 1049012, QuestGump.LocalizedWhite , false , false ); // No thanks, I decline.
			AddImage( 372, 57, 1417);
			AddImage( 381, 66, 5576); 

			if( quest.OfferNumber > 0 )
				AddHtmlLocalized( 105, 159, 299, 182, quest.OfferNumber, QuestGump.LocalizedYellow, false, true ); // (conversation)
			else
				AddHtml( 105, 159, 299, 182, QuestGump.Color( quest.OfferString, QuestGump.HtmlYellow ), false, true ); // (conversation)
		}

		public override void OnResponse( Server.Network.NetState state, RelayInfo info )
		{
			PlayerMobile from = state.Mobile as PlayerMobile;

			if ( info.Switches[0] == 1 )
			{
				from.SendLocalizedMessage( 1049019 ); // You have accepted the Quest.
				from.PlaySound( m_Quest.QuestAcceptSound );

				m_Quest.Start();

				from.SendGump( new StartQuestGump( m_Quest ) );
				from.SendGump( new QuestLogUpdated() );
			}
			else
			{
				from.CurrentQuest = null;
				from.SendLocalizedMessage( 1049018 ); // You have declined the Quest.		
			}
		}
	}

	public class StartQuestGump : Gump
	{
		public StartQuestGump( BaseQuest quest ) : base( 0, 0 )
		{
			Closable = false;
			Dragable = true;

			AddPage(0);
			AddImageTiled(  54, 43, 386, 343, 2624 );
			AddAlphaRegion( 54, 43, 386, 343 );

			AddImage( 79, 71, 9781);
			AddImageTiled( 64, 19, 363, 29, 9391 );
			AddImageTiled( 52, 34, 6, 340, 9203 );
			AddImageTiled( 37, 19, 102, 29, 9390 );
			AddImageTiled( 48, 374, 371, 29, 9391 );
			AddImageTiled( 36, 374, 105, 29, 9390 );
			AddImageTiled( 437, 34, 6, 344, 9203 );
			AddImageTiled( 345, 19, 110, 29, 9392 );
			AddImageTiled( 339, 374, 114, 29, 9392 );
			AddImageTiled( 66, 24, 367, 17, 10101 );
			AddImage( 425, 24, 10104 );
			AddImage( 2, 11, 10440 );
			AddHtmlLocalized( 118, 75, 200, 30, 1049069, QuestGump.LocalizedWhite, false , false ); // Conversation Event
			AddImageTiled( 82, 107, 190, 1, 9203 );
			AddImage( 369, 57, 223 );

			AddButton( 212, 342, 2313, 2312, 55, GumpButtonType.Reply, 0 );

			if( quest.StartNumber > 0 )
				AddHtmlLocalized( 74, 124, 349, 209, quest.StartNumber, QuestGump.LocalizedYellow, false, true ); // (conversation)
			else
				AddHtml( 74, 124, 349, 209, QuestGump.Color( quest.StartString, QuestGump.HtmlYellow ), false, true ); // (conversation)
		}
	}

	public class QuestInProgressGump : Gump
	{

		public QuestInProgressGump( BaseQuest quest ) : base( 10, 10 )
		{
			Closable = false;
			Dragable = true;

			AddPage(0);
			AddImageTiled(  54, 43, 386, 343, 2624 );
			AddAlphaRegion( 54, 43, 386, 343 );

			AddImage( 79, 71, 9781);
			AddImageTiled( 64, 19, 363, 29, 9391);
			AddImageTiled( 52, 34, 6, 340, 9203);
			AddImageTiled( 37, 19, 102, 29, 9390);
			AddImageTiled( 48, 374, 371, 29, 9391);
			AddImageTiled( 36, 374, 105, 29, 9390);
			AddImageTiled( 437, 34, 6, 344, 9203);
			AddImageTiled( 345, 19, 110, 29, 9392);
			AddImageTiled( 339, 374, 114, 29, 9392);
			AddImageTiled( 66, 24, 367, 17, 10101);
			AddImage( 425, 24, 10104);
			AddImage( 2, 11, 10440);
			AddHtmlLocalized(118, 75, 200, 30, 1049069, QuestGump.LocalizedWhite , false , false ); // Conversation Event
			AddImageTiled( 82, 107, 190, 1, 9203);
			AddImage( 369, 57, 223);

			AddButton( 212, 342, 2313, 2312, 55, GumpButtonType.Reply, 0 );

			if( quest.InProgressNumber > 0)
				AddHtmlLocalized( 74, 124, 349, 209, quest.InProgressNumber, QuestGump.LocalizedYellow, false, true ); // (conversation)
			else
				AddHtml( 74, 124, 349, 209, QuestGump.Color( quest.InProgressString, QuestGump.HtmlYellow ), false, true ); // (conversation)
		}
	}

	public class CancelQuestGump : Gump
	{
		private BaseQuest m_Quest;

		public CancelQuestGump( BaseQuest quest ) : base( 10, 10 )
		{
			m_Quest = quest;

			Closable = false;
			Dragable = true;

			AddPage( 0 );
			AddImageTiled(  81, 96, 329, 266, 2624 );
			AddAlphaRegion( 81, 96, 329, 266 );

			AddImage( 396, 347, 10006 );
			AddImage( 83, 347, 10006 );
			AddImage( 396, 98, 10006 );
			AddImage( 83, 97, 10006 );
			AddImage( 98, 344, 10102 );
			AddImage( 98, 96, 10102 );
			AddImage( 377, 344, 10104 );
			AddImage( 377, 96, 10104 );
			AddImage( 393, 113, 10152 );
			AddImage( 81, 113, 10152 );
			AddImage( 81, 329, 10154 );
			AddImage( 393, 329, 10154 );

			AddImageTiled( 113, 96, 264, 17, 10101 );
			AddImageTiled( 113, 344, 264, 17, 10101 );
			AddImageTiled( 81, 125, 17, 204, 10153 );
			AddImageTiled( 393, 125, 17, 204, 10153 );
			AddImageTiled( 110, 136, 220, 4, 9357 );

			AddImage( 109, 238, 9703 );
			AddImage( 109, 175, 9703 );

			AddRadio( 106, 275, 9721, 9724, true, 1 );
			AddRadio( 106, 309, 9721, 9724, false, 2 );

			AddHtmlLocalized( 110, 116, 200, 17, 1049000, QuestGump.LocalizedRed, false, false ); // Confirm Quest Cancellation
			AddHtmlLocalized( 110, 153, 200, 17, 1049001, QuestGump.LocalizedWhite, false, false ); // You have chosen to abort your quest:

			if( quest.QuestNameNumber > 0 )
				AddHtmlLocalized( 128, 174, 200, 17, quest.QuestNameNumber, QuestGump.LocalizedGreen, false, false );
			else
				AddHtml( 128, 174, 200, 17, QuestGump.Color( quest.QuestNameString, QuestGump.HtmlGreen ), false, false );
				
			AddHtmlLocalized( 110, 215, 200, 17, 1049002, QuestGump.LocalizedWhite, false, false ); // Can this quest be restarted after quitting?
			AddHtmlLocalized( 128, 236, 200, 17, ( quest.Restartable ? 1049016 : 1049017 ), QuestGump.LocalizedGreen, false, false ); // Yes / No
			AddHtmlLocalized( 140, 280, 200, 17, 1049005, QuestGump.LocalizedWhite, false, false ); // Yes, I really want to quit!
			AddHtmlLocalized( 140, 315, 200, 17, 1049006, QuestGump.LocalizedWhite, false, false ); // No, I don't want to quit.

			AddButton( 334, 319, 2130, 2129, 32, GumpButtonType.Reply, 0 );
		}

		public override void OnResponse( Server.Network.NetState state, RelayInfo info )
		{
			PlayerMobile from = state.Mobile as PlayerMobile;

			if( info.Switches[0] == 1 )
			{
				m_Quest.Cancel();
				from.SendLocalizedMessage( 1049015 ); // You have canceled your quest.
			}
			else
				from.SendLocalizedMessage( 1049014 ); // You have chosen not to cancel your quest.
		}
	}

	public class FinishQuestGump : Gump
	{
		public FinishQuestGump( BaseQuest quest ) : this( quest, 0 )
		{
		}

		public FinishQuestGump( BaseQuest quest, int cliloc ) : base( 10, 10 )
		{
			Closable = false;
			Dragable = true;

			AddPage( 0 );
			AddImageTiled( 54, 43, 386, 343, 2624 );
			AddAlphaRegion( 54, 43, 386, 343 );

			AddImage( 79, 71, 9781);
			AddImageTiled( 64, 19, 363, 29, 9391 );
			AddImageTiled( 52, 34, 6, 340, 9203 );
			AddImageTiled( 37, 19, 102, 29, 9390 );
			AddImageTiled( 48, 374, 371, 29, 9391 );
			AddImageTiled( 36, 374, 105, 29, 9390 );
			AddImageTiled( 437, 34, 6, 344, 9203 );
			AddImageTiled( 345, 19, 110, 29, 9392 );
			AddImageTiled( 339, 374, 114, 29, 9392 );
			AddImageTiled( 66, 24, 367, 17, 10101 );
			AddImage( 425, 24, 10104 );
			AddImage( 2, 11, 10440 );

			AddHtmlLocalized(118, 75, 200, 30, 1049069, QuestGump.LocalizedWhite , false , false ); // Conversation Event
			AddImageTiled( 82, 107, 190, 1, 9203 );
			AddImage( 369, 57, 223 );

			AddButton( 212, 342, 2313, 2312, 55, GumpButtonType.Reply, 0 );

			if( cliloc > 0 )
			{
				AddHtmlLocalized( 74, 124, 349, 209, cliloc, QuestGump.LocalizedYellow, false, true ); // (conversation)
			}
			else
			{
				if( quest.FinishNumber > 0 )
					AddHtmlLocalized( 74, 124, 349, 209, quest.FinishNumber, QuestGump.LocalizedYellow, false, true ); // (conversation)
				else
					AddHtml( 74, 124, 349, 209, QuestGump.Color( quest.FinishString, QuestGump.HtmlYellow ), false, true ); // (conversation)
			}

			quest.Finish();
		}
	}

	public class OccupiedQuestGump : Gump
	{
		private int m_OccupiedNumber = 0;
		private string m_OccupiedString	= ""; 

		public OccupiedQuestGump() : this( 500310 )	// You are too busy with something else.
		{
		}
		
		public OccupiedQuestGump( int message ) : base( 10, 10 )
		{
			m_OccupiedNumber = (int) message;

			Closable = false;
			Dragable = true;

			AddPage( 0 );
			AddImageTiled( 54, 43, 386, 343, 2624 );
			AddAlphaRegion( 54, 43, 386, 343 );

			AddImage( 79, 71, 9781);
			AddImageTiled( 64, 19, 363, 29, 9391 );
			AddImageTiled( 52, 34, 6, 340, 9203 );
			AddImageTiled( 37, 19, 102, 29, 9390 );
			AddImageTiled( 48, 374, 371, 29, 9391 );
			AddImageTiled( 36, 374, 105, 29, 9390 );
			AddImageTiled( 437, 34, 6, 344, 9203 );
			AddImageTiled( 345, 19, 110, 29, 9392 );
			AddImageTiled( 339, 374, 114, 29, 9392 );
			AddImageTiled( 66, 24, 367, 17, 10101 );
			AddImage( 425, 24, 10104 );
			AddImage( 2, 11, 10440 );

			AddHtmlLocalized(118, 75, 200, 30, 1049069, QuestGump.LocalizedWhite, false , false ); // Conversation Event
			AddImageTiled( 82, 107, 190, 1, 9203 );
			AddImage( 369, 57, 223 );

			AddButton( 212, 342, 2313, 2312, 55, GumpButtonType.Reply, 0 );
			AddHtmlLocalized( 74, 124, 349, 209, m_OccupiedNumber, QuestGump.LocalizedYellow, false, true ); // (conversation)
		}

		public OccupiedQuestGump( string message ) : base( 10, 10 )
		{
			m_OccupiedString = (string) message;

			Closable = false;
			Dragable = true;

			AddPage( 0 );
			AddImageTiled( 54, 43, 386, 343, 2624 );
			AddAlphaRegion( 54, 43, 386, 343 );

			AddImage( 79, 71, 9781);
			AddImageTiled( 64, 19, 363, 29, 9391 );
			AddImageTiled( 52, 34, 6, 340, 9203 );
			AddImageTiled( 37, 19, 102, 29, 9390 );
			AddImageTiled( 48, 374, 371, 29, 9391 );
			AddImageTiled( 36, 374, 105, 29, 9390 );
			AddImageTiled( 437, 34, 6, 344, 9203 );
			AddImageTiled( 345, 19, 110, 29, 9392 );
			AddImageTiled( 339, 374, 114, 29, 9392 );
			AddImageTiled( 66, 24, 367, 17, 10101 );
			AddImage( 425, 24, 10104 );
			AddImage( 2, 11, 10440 );

			AddHtmlLocalized(118, 75, 200, 30, 1049069, QuestGump.LocalizedWhite, false , false ); // Conversation Event
			AddImageTiled( 82, 107, 190, 1, 9203 );
			AddImage( 369, 57, 223 );

			AddButton( 212, 342, 2313, 2312, 55, GumpButtonType.Reply, 0 );
			AddHtml( 74, 124, 349, 209, QuestGump.Color( m_OccupiedString, QuestGump.HtmlYellow ), false, true ); // (conversation)
		}
	}

	public class RestingQuestGump : Gump
	{
		private int m_OccupiedNumber = 0;
		private string m_OccupiedString	= ""; 

		public RestingQuestGump() : base( 10, 10 )
		{
			Closable = false;
			Dragable = true;

			AddPage( 0 );
			AddImageTiled( 54, 43, 386, 343, 2624 );
			AddAlphaRegion( 54, 43, 386, 343 );

			AddImage( 79, 71, 9781);
			AddImageTiled( 64, 19, 363, 29, 9391 );
			AddImageTiled( 52, 34, 6, 340, 9203 );
			AddImageTiled( 37, 19, 102, 29, 9390 );
			AddImageTiled( 48, 374, 371, 29, 9391 );
			AddImageTiled( 36, 374, 105, 29, 9390 );
			AddImageTiled( 437, 34, 6, 344, 9203 );
			AddImageTiled( 345, 19, 110, 29, 9392 );
			AddImageTiled( 339, 374, 114, 29, 9392 );
			AddImageTiled( 66, 24, 367, 17, 10101 );
			AddImage( 425, 24, 10104 );
			AddImage( 2, 11, 10440 );

			AddHtmlLocalized(118, 75, 200, 30, 1049069, QuestGump.LocalizedWhite, false , false ); // Conversation Event
			AddImageTiled( 82, 107, 190, 1, 9203 );
			AddImage( 369, 57, 223 );

			AddButton( 212, 342, 2313, 2312, 55, GumpButtonType.Reply, 0 );
			AddHtml( 74, 124, 349, 209, QuestGump.Color( "I am in need of assistance but you look quite tired.<BR><BR>If you are still on a quest you must quit it before you can help me.<BR><BR>Otherwise, rest for about an hour between adventures, only then will you be ready to embark on your next mission." , QuestGump.HtmlYellow ), false, true );
		}
	}

	public class OverLoadedGump : Gump
	{
		public OverLoadedGump( BaseQuest quest ) : base( 10, 10 )
		{
			Closable = false;
			Dragable = true;

			AddPage(0);
			AddImageTiled(  54, 43, 386, 343, 2624 );
			AddAlphaRegion( 54, 43, 386, 343 );

			AddImage( 79, 71, 9781);
			AddImageTiled( 64, 19, 363, 29, 9391);
			AddImageTiled( 52, 34, 6, 340, 9203);
			AddImageTiled( 37, 19, 102, 29, 9390);
			AddImageTiled( 48, 374, 371, 29, 9391);
			AddImageTiled( 36, 374, 105, 29, 9390);
			AddImageTiled( 437, 34, 6, 344, 9203);
			AddImageTiled( 345, 19, 110, 29, 9392);
			AddImageTiled( 339, 374, 114, 29, 9392);
			AddImageTiled( 66, 24, 367, 17, 10101);
			AddImage( 425, 24, 10104);
			AddImage( 2, 11, 10440);
			AddHtmlLocalized(118, 75, 200, 30, 1049069, QuestGump.LocalizedWhite , false , false ); // Conversation Event
			AddImageTiled( 82, 107, 190, 1, 9203);
			AddImage( 369, 57, 223);

			AddButton( 212, 342, 2313, 2312, 55, GumpButtonType.Reply, 0 );

			if( quest.InProgressNumber > 0)
				AddHtmlLocalized( 74, 124, 349, 209, quest.OverLoadedNumber, QuestGump.LocalizedYellow, false, true ); // (conversation)
			else
				AddHtml( 74, 124, 349, 209, QuestGump.Color( quest.OverLoadedString, QuestGump.HtmlYellow ), false, true ); // (conversation)
		}
	}

	public class QuestLogUpdated : Gump 
	{ 
		public QuestLogUpdated() : base( 3, 30 ) 
		{ 
			AddPage( 0 ); 

			AddImage( 20, 5, 0x589 ); 
			AddHtmlLocalized( 0, 78, 120, 40, 1049079, QuestGump.LocalizedWhite, false, false ); 
			AddImageTiled( 0, 78, 120, 40, 0xA40 ); 
			AddAlphaRegion( 0, 78, 120, 40 ); 
			AddButton( 30, 15, 0x15C7, 0x15C8, 0x1, GumpButtonType.Reply, 0 ); 
		} 

		public override void OnResponse( NetState state, RelayInfo info ) 
		{ 
			Mobile from = state.Mobile; 
			PlayerMobile m = (PlayerMobile) from; 
			 
			switch( info.ButtonID ) 
			{ 
				case 1: 
				{ 
					if( m.CurrentQuest == null ) 
					{ 
						from.CloseGump( typeof( QuestLogUpdated ) ); 
						from.CloseGump( typeof( QuestLogGump ) ); 
						break; 
					} 
					else 
					{ 
						from.CloseGump( typeof( QuestLogUpdated ) ); 
						from.CloseGump( typeof( QuestLogGump ) ); 
						from.SendGump( new QuestLogGump( m.CurrentQuest ) ); 
						break; 
					} 
				} 
			} 
		}
	}
}