using System; 
using System.IO; 
using System.Collections; 
using Server.Items;
using Server.Misc; 
using Server.Gumps;
using Server.ContextMenus;
using Server.Mobiles;
using Server.Accounting;

namespace Server.Mobiles 
{ 
	public class Santa : BaseCreature 
	{  

		[Constructable] 
		public Santa() : base(AIType.AI_Thief, FightMode.None, 10, 1, 0.8, 2.6 ) 
		{ 
			InitStats( 100, 100, 100 ); 

			Name = "Santa Claus"; 
			Female = false; 
			Body = 0x190; 
			Hue = Utility.RandomSkinHue(); 
			NameHue = 0x35;  
			Blessed = true;
			AddItem( new FancyShirt( 0x85 ) ); 
			AddItem( new LongPants( 0x85 ) );
			AddItem( new Boots() ); 

			Item hair = new Item( 0x203C );  
			hair.Layer = Layer.Hair; 
			hair.Movable = false; 
			AddItem( hair );
			Item beard = new Item(  0x203E );
			beard.Layer = Layer.FacialHair;
			beard.Movable = false;
			AddItem( beard );
		} 
      
		public Santa( Serial serial ) : base( serial ) 
		{ 
		} 

		public override void Serialize( GenericWriter writer ) 
		{ 
			base.Serialize( writer ); 

			writer.Write( (int) 0 ); // version 
		} 

		public override void Deserialize( GenericReader reader ) 
		{ 
			base.Deserialize( reader ); 

			int version = reader.ReadInt(); 
		}

		public override void GetContextMenuEntries( Mobile from, ArrayList list ) 
		{ 
			base.GetContextMenuEntries( from, list ); 
			list.Add( new SantaEntry( from ) ); 
		}

		public override void OnSpeech( SpeechEventArgs args ) 
		{
			Mobile m = args.Mobile;
			Account acct=(Account)m.Account;
			bool Xmas = Convert.ToBoolean( acct.GetTag("Xmas") );

			if( args.Mobile.InRange( this, 2 )) 
			{ 
				if (( args.Speech.ToLower().IndexOf( "gift" ) >= 0 ) ||  ( args.Speech.ToLower().IndexOf( "present" ) >= 0 ))
				{ 
					if( !Xmas )
					{
						XmasBag xbag = new XmasBag( 1 );
						this.Say( "Here are your christmas gifts!    Ho Ho Ho! Merry Christmas!" );
						acct.SetTag( "Xmas", "true" );
						if ( !m.AddToBackpack( xbag ) )
							xbag.Delete();
					}
					
					else 
					{
						this.Say ( "You have already recieved your gifts {0}, You will have to wait till next year! Ho Ho Ho!", m.Name );
					}
				}
				else 
				{
					this.Say ( "Greetings {0}, Merry Christmas! Ho Ho Ho!", m.Name );
				}
			}  
		}
		public class SantaEntry : ContextMenuEntry
		{
			private Mobile m_Mobile;

			public SantaEntry( Mobile from ) : base( 6146, 3 )
			{
				m_Mobile = from;
			}
          
			public override void OnClick()
			{
				PlayerMobile mobile = (PlayerMobile) m_Mobile;
				Account acct=(Account)mobile.Account;
				bool ChristmasQuest = Convert.ToBoolean( acct.GetTag("ChristmasQuest") );
				
				if( !( m_Mobile is PlayerMobile ) )
					return;
				if( ChristmasQuest )
				{
					mobile.SendMessage ( "You have rescued Santa's Reindeer and were rewarded, You did a fantastic job.. Thank You Again {0}.", mobile.Name );
					return;
				}

				if( mobile.CurrentQuest == null )
				{
					if( mobile.CanStartNewQuest )
					{
						if ( ! mobile.HasGump( typeof( OfferQuestGump ) ) )
						{
							mobile.CurrentQuest = new ChristmasQuest( mobile );
							mobile.SendGump( new OfferQuestGump( mobile.CurrentQuest ) );
						}
					}
					else
					{
						mobile.SendGump( new RestingQuestGump() );
					}
				}
				else if( mobile.CurrentQuest is ChristmasQuest )
				{
					ChristmasQuest quest = (ChristmasQuest) mobile.CurrentQuest;
						
					if( quest.Completed )
					{
						if( quest.CanRecieveItem( mobile, new SantasElixer() ) )
						{
							mobile.PlaySound( 1073 );
							acct.SetTag( "ChristmasQuest", "true" );
							mobile.SendGump( new FinishQuestGump( quest ) );
						}
						else
						{
							mobile.SendGump( new OverLoadedGump( quest ) );
						}
					}
					else
					{
						mobile.PlaySound( 1090 );
						mobile.SendGump( new QuestInProgressGump( mobile.CurrentQuest ) );
					}
				}
				else
				{
					mobile.SendGump( new OccupiedQuestGump( "<i>Santa looks up with desperate eyes...</i><BR><BR>You seem to be a bit busy at the moment, please come back and see me when you have more time. I have some trouble and if i dont get help christmas may be ruined this year." ) );
				}
			}
		}
	} 
}