using System; 
using Server;
using Server.Items;
using Server.Mobiles; 
using Server.Gumps;

namespace Server.Misc
{
	public class BlackMatriarchQuest1 : BaseQuest
	{
		public override int QuestNameNumber{ get { return 1054147; } }
		public override int OfferNumber{ get{ return 1054082; } }
		public override int StartNumber{ get{ return 1054084; } }
		public override int FinishNumber{ get{ return 1054091; } }
		public override int InProgressNumber{ get{ return 1054089; } }
		public override int LogObjectiveNumber{ get{ return 1054087; } }
		public override int LogStartObjectiveNumber{ get{ return 1054085; } }	
		public override int LogFinishObjectiveNumber{ get{ return 1054090; } }
		public override int QuestAcceptSound{ get{ return 602; } }

		public BlackMatriarchQuest1( PlayerMobile player ) : base( player )
		{
			Objectives.Add( new QuestObjective( "Infiltrator 1" ) );
			Objectives.Add( new QuestObjective( "Infiltrator 2" ) );
			Objectives.Add( new QuestObjective( "Infiltrator 3" ) );
			Objectives.Add( new QuestObjective( "Infiltrator 4" ) );
			Objectives.Add( new QuestObjective( "Infiltrator 5" ) );
			Objectives.Add( new QuestObjective( "Infiltrator 6" ) );
			Objectives.Add( new QuestObjective( "Infiltrator 7" ) );
		}

		public BlackMatriarchQuest1( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 ); // version
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
		}
	}

	public class BlackMatriarchQuest2 : BaseQuest
	{		
		public override int QuestNameNumber{ get { return 1054147; } }
		public override int FinishNumber{ get{ return 1054096; } }
		public override int InProgressNumber{ get{ return 1054094; } }
		public override int LogObjectiveNumber{ get{ return 1054093; } }
		public override int LogStartObjectiveNumber{ get{ return 1054092; } }	
		public override int LogFinishObjectiveNumber{ get{ return 1054095; } }	

		public BlackMatriarchQuest2( PlayerMobile player ) : base( player )
		{
			Objectives.Add( new QuestObjective( "8 Gallons of Water" ) );
		}

		public BlackMatriarchQuest2( Serial serial ) : base( serial )
		{
		}

		public override int TotalObjectives
		{
			get
			{
				return 8;
			}
		}

		public int m_Number = 0;

		public override bool CheckTargetedItem( Object o, Item m_Item, PlayerMobile player)
		{
			if( o is BaseBeverage)
			{
				BaseBeverage bev = o as BaseBeverage;
				if ( m_Item.ItemID == 0x14DE || m_Item.ItemID == 0x1558 ||
					m_Item.ItemID == 0x14DF || m_Item.ItemID == 0x1552 ||
					m_Item.ItemID == 0x1554 || m_Item.ItemID == 0x1559 ||
					m_Item.ItemID == 0x1550 || m_Item.ItemID == 0x14D7 || m_Item.ItemID == 0x1555)
				{
					if(bev.IsFull && bev.Content==BeverageType.Water && bev is Pitcher)
					{
						bev.Quantity = 0;
						player.PlaySound( 0x4E );

						if ( m_Number < 8 )
						{
							m_Number++;
						}
						if( m_Number > 7 )
						{
							( (QuestObjective) this.Objectives[ 0 ] ).Completed = true;
							player.SendGump( new QuestLogUpdated() );
						}
						return true;
					}
					else if( bev.Content==BeverageType.Water )
					{
						bev.Quantity --;
						player.PlaySound( 0x4E );
						return true;
					}
				}
			}
			return false;
		}

		public override int CompletedObjectives
		{
			get
			{
				return m_Number;
			}
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 ); // version
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
		}
	}

	public class BlackMatriarchQuest3 : BaseQuest
	{
		public override int QuestNameNumber{ get { return 1054147; } }
		public override int OfferNumber{ get{ return 1054083; } }
		public override int StartNumber{ get{ return 1054084; } }
		public override int FinishNumber{ get{ return 1054091; } }
		public override int InProgressNumber{ get{ return 1054089; } }
		public override int LogObjectiveNumber{ get{ return 1054087; } }
		public override int LogStartObjectiveNumber{ get{ return 1054085; } }	
		public override int LogFinishObjectiveNumber{ get{ return 1054090; } }
		public override int QuestAcceptSound{ get{ return 602; } }

		public BlackMatriarchQuest3( PlayerMobile player ) : base( player )
		{
			Objectives.Add( new QuestObjective( "Infiltrator 1" ) );
			Objectives.Add( new QuestObjective( "Infiltrator 2" ) );
			Objectives.Add( new QuestObjective( "Infiltrator 3" ) );
			Objectives.Add( new QuestObjective( "Infiltrator 4" ) );
			Objectives.Add( new QuestObjective( "Infiltrator 5" ) );
			Objectives.Add( new QuestObjective( "Infiltrator 6" ) );
			Objectives.Add( new QuestObjective( "Infiltrator 7" ) );
		}

		public BlackMatriarchQuest3( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 ); // version
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
		}
	}

	public class BlackMatriarchQuest4 : BaseQuest
	{		
		public override int QuestNameNumber{ get { return 1054147; } }
		public override int FinishNumber{ get{ return 1054097; } }
		public override int InProgressNumber{ get{ return 1054094; } }
		public override int LogObjectiveNumber{ get{ return 1054093; } }
		public override int LogStartObjectiveNumber{ get{ return 1054092; } }	
		public override int LogFinishObjectiveNumber{ get{ return 1054095; } }	

		public BlackMatriarchQuest4( PlayerMobile player ) : base( player )
		{
			Objectives.Add( new QuestObjective( "8 Gallons of Water" ) );
		}

		public BlackMatriarchQuest4( Serial serial ) : base( serial )
		{
		}

		public override int TotalObjectives
		{
			get
			{
				return 8;
			}
		}

		public int m_Number = 0;

		public override bool CheckTargetedItem( Object o, Item m_Item, PlayerMobile player)
		{
			if( o is BaseBeverage)
			{
				BaseBeverage bev = o as BaseBeverage;
				if ( m_Item.ItemID == 0x14DE || m_Item.ItemID == 0x1558 ||
					m_Item.ItemID == 0x14DF || m_Item.ItemID == 0x1552 ||
					m_Item.ItemID == 0x1554 || m_Item.ItemID == 0x1559 ||
					m_Item.ItemID == 0x1550 || m_Item.ItemID == 0x14D7 || m_Item.ItemID == 0x1555)
				{
					if(bev.IsFull && bev.Content==BeverageType.Water && bev is Pitcher)
					{
						bev.Quantity = 0;
						player.PlaySound( 0x4E );

						if ( m_Number < 8 )
						{
							m_Number++;
						}
						if( m_Number > 7 )
						{
							( (QuestObjective) this.Objectives[ 0 ] ).Completed = true;
							player.SendGump( new QuestLogUpdated() );
						}
						return true;
					}
					else if( bev.Content==BeverageType.Water )
					{
						bev.Quantity --;
						player.PlaySound( 0x4E );
						return true;
					}
				}
			}
			return false;
		}

		public override int CompletedObjectives
		{
			get
			{
				return m_Number;
			}
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 ); // version
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
		}
	}

	public class BlackMatriarchQuest5 : BaseQuest
	{		
		public override int OfferNumber{ get{ return 1054099; } }
		public override int StartNumber{ get{ return 1054099; } }
		public override int FinishNumber{ get{ return 1054101; } }
		public override int InProgressNumber{ get{ return 1054099; } }	
		public override int LogStartObjectiveNumber{ get{ return 1054098; } }	
		public override int QuestAcceptSound{ get{ return 602; } }
		public override int OverLoadedNumber{ get{ return 1054102; } }

		public BlackMatriarchQuest5( PlayerMobile player ) : base( player )
		{
			Objectives.Add( new QuestObjective( "Transform up to 200 Zoogi to Powder" ) );
		}

		public BlackMatriarchQuest5( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 ); // version
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
		}
	}
}