using System;
using System.Collections;
using Server.Items;
using Server.Mobiles;
using Server.Misc;
using Server.Targeting;
using Server.Gumps;

namespace Server.Mobiles
{
	[CorpseName( "a solen infiltrator corpse" )]
	public class BlackSolenInfiltratorWarrior : BaseCreature
	{
		[Constructable]
		public BlackSolenInfiltratorWarrior() : base( AIType.AI_Melee, FightMode.Closest, 10, 1, 0.2, 0.4 )
		{
			Name = "a black solen infiltrator";
			Body = 806;
			BaseSoundID = 959;
			Hue = 0x453;

			SetStr( 206, 230 );
			SetDex( 121, 145 );
			SetInt( 66, 90 );

			SetHits( 96, 107 );

			SetDamage( 5, 15 );

			SetDamageType( ResistanceType.Physical, 80 );
			SetDamageType( ResistanceType.Poison, 20 );

			SetResistance( ResistanceType.Physical, 20, 35 );
			SetResistance( ResistanceType.Fire, 20, 35 );
			SetResistance( ResistanceType.Cold, 10, 25 );
			SetResistance( ResistanceType.Poison, 20, 35 );
			SetResistance( ResistanceType.Energy, 10, 25 );

			SetSkill( SkillName.MagicResist, 80.0 );
			SetSkill( SkillName.Tactics, 80.0 );
			SetSkill( SkillName.Wrestling, 80.0 );

			Fame = 3000;
			Karma = -3000;

			VirtualArmor = 40;

			int gems = Utility.RandomMinMax( 1, 4 );

			for ( int i = 0; i < gems; ++i )
				PackGem();

			SolenHelper.PackPicnicBasket( this );

			int zoogicount = Utility.RandomMinMax( 3, 13 );
			ZoogiFungus zoogi= new ZoogiFungus();
			zoogi.Amount=zoogicount;
			PackItem( zoogi );
		}
		
		public override void GenerateLoot()
		{
			AddLoot( LootPack.AosAverage, 1 );
		}		

		public override bool IsEnemy( Mobile m )
		{
			PlayerMobile mobile = m as PlayerMobile; 
			
			if ( m is RedSolenWorker || m is RedSolenQueen || m is RedSolenWarrior || m is RedSolenInfiltratorQueen || m is RedSolenInfiltratorWarrior )
				return true;
		
			if ( mobile != null )
			{
				if( mobile.SolenFriendship == SolenFriend.Black )
					return false;
			}
			return base.IsEnemy( m );
		}

		public override void OnDamage( int amount, Mobile attacker, bool willKill )
		{
			if( attacker is PlayerMobile )
			{
				PlayerMobile mobile = attacker as PlayerMobile;

				if( mobile.SolenFriendship == SolenFriend.Black )
				{
					mobile.SolenFriendship = SolenFriend.None;
					mobile.SendLocalizedMessage( 1054103 );
				}
			}
			base.OnDamage( amount, attacker, willKill );
		}

		public void GiveKillCount()
		{
			ArrayList toGive = new ArrayList();

			ArrayList list = Aggressors;
			for ( int i = 0; i < list.Count; ++i )
			{
				AggressorInfo info = (AggressorInfo)list[i];

				if ( info.Attacker.Player &&  (DateTime.Now - info.LastCombatTime) < TimeSpan.FromSeconds( 30.0 ) && !toGive.Contains( info.Attacker ) )
					toGive.Add( info.Attacker );
			}

			list = Aggressed;
			for ( int i = 0; i < list.Count; ++i )
			{
				AggressorInfo info = (AggressorInfo)list[i];

				if ( info.Defender.Player &&  (DateTime.Now - info.LastCombatTime) < TimeSpan.FromSeconds( 30.0 ) && !toGive.Contains( info.Defender ) )
					toGive.Add( info.Defender );
			}

			if ( toGive.Count == 0 )
				return;

			for ( int i = 0; i < toGive.Count; ++i )
			{
				Mobile m = (Mobile)toGive[i % toGive.Count];

				if( !(m is PlayerMobile) )
					return;

				PlayerMobile mobile = m as PlayerMobile;

				if( mobile.CurrentQuest == null )
					return;

				BaseQuest quest = mobile.CurrentQuest;
				int m_Number = quest.CompletedObjectives;
			
				if ( mobile != null ) 
				{ 
					if ( quest is RedMatriarchQuest1 || quest is RedMatriarchQuest3 )
					{
						if( m_Number == 7 )
							return;

						( (QuestObjective) quest.Objectives[ m_Number ] ).Completed = true;
						
						if( quest.Completed )
						{
							mobile.SendGump( new QuestLogUpdated() );
						}
					}
					return;
				}
				return;
			}
		}

		public override bool OnBeforeDeath()
		{
			if ( !NoKillAwards )
			{
				GiveKillCount();
			}
				
			return base.OnBeforeDeath();
		}

		public override int GetAngerSound()
		{
			return 0xB5;
		}

		public override int GetIdleSound()
		{
			return 0xB5;
		}

		public override int GetAttackSound()
		{
			return 0x289;
		}

		public override int GetHurtSound()
		{
			return 0xBC;
		}

		public override int GetDeathSound()
		{
			return 0xE4;
		}

		public BlackSolenInfiltratorWarrior( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
		}
	}
}