using System;
using System.Collections;
using Server.Items;
using Server.Targeting;
using Server.ContextMenus;
using Server.Gumps;
using Server.Misc;
using Server.Engines.Plants;

namespace Server.Mobiles
{
	[CorpseName( "a solen matriarch corpse" )]
	public class BlackSolenMatriarch : BaseCreature
	{
		[Constructable]
		public BlackSolenMatriarch() : base(AIType.AI_Thief, FightMode.None, 10, 1, 0.8, 2.6 )
		{
			Name = "The Solen Matriarch";
			Body = 807;
			BaseSoundID = 959;
			Hue = 0x453;
			Blessed = true;
			SetStr( 296, 320 );
			SetDex( 121, 145 );
			SetInt( 76, 100 );

			SetHits( 151, 162 );

			SetDamage( 10, 15 );

			SetDamageType( ResistanceType.Physical, 70 );
			SetDamageType( ResistanceType.Poison, 30 );

			SetResistance( ResistanceType.Physical, 30, 40 );
			SetResistance( ResistanceType.Fire, 30, 35 );
			SetResistance( ResistanceType.Cold, 25, 35 );
			SetResistance( ResistanceType.Poison, 35, 40 );
			SetResistance( ResistanceType.Energy, 25, 30 );

			SetSkill( SkillName.MagicResist, 70.0 );
			SetSkill( SkillName.Tactics, 90.0 );
			SetSkill( SkillName.Wrestling, 90.0 );

			Fame = 4500;
			Karma = -4500;

			VirtualArmor = 45;

		}

		public BlackSolenMatriarch( Serial serial ) : base( serial )
		{
		}

		public override void GetContextMenuEntries( Mobile from, ArrayList list ) 
		{ 
			base.GetContextMenuEntries( from, list ); 
			list.Add( new MatriarchEntry( from ) ); 
		}

		public class MatriarchEntry : ContextMenuEntry
		{
			private Mobile m_Mobile;

			public MatriarchEntry( Mobile from ) : base( 6146, 3 )
			{
				m_Mobile = from;
			}
          
			public override void OnClick()
			{
				if( !( m_Mobile is PlayerMobile ) )
					return;

				PlayerMobile mobile = (PlayerMobile) m_Mobile;
				BaseQuest quest = mobile.CurrentQuest;

				if( quest is BlackMatriarchQuest1 )
				{
					if( quest.Completed )
					{
						mobile.PlaySound( 602 );
						mobile.SendGump( new FinishQuestGump( quest ) );
						mobile.CurrentQuest = new BlackMatriarchQuest2( mobile );
						mobile.SendGump( new QuestLogUpdated() );				
					}
					else
					{
						mobile.PlaySound( 599 );
						mobile.SendGump( new QuestInProgressGump( mobile.CurrentQuest ) );
					}						
				}
				else if( quest is BlackMatriarchQuest2 )
				{
					if( quest.Completed )
					{
						mobile.PlaySound( 602 );
						mobile.SendGump( new FinishQuestGump( quest ) );
						mobile.CurrentQuest = new BlackMatriarchQuest5( mobile );
						mobile.SendGump( new QuestLogUpdated() );
						mobile.SolenFriendship = SolenFriend.Black;				
					}
					else
					{
						mobile.PlaySound( 599 );
						mobile.SendGump( new QuestInProgressGump( mobile.CurrentQuest ) );
					}
				}
				else if( quest is BlackMatriarchQuest3 )
				{
					if( quest.Completed )
					{
						mobile.PlaySound( 602 );
						mobile.SendGump( new FinishQuestGump( quest ) );
						mobile.CurrentQuest = new BlackMatriarchQuest4( mobile );
						mobile.SendGump( new QuestLogUpdated() );			
					}
					else
					{
						mobile.PlaySound( 599 );
						mobile.SendGump( new QuestInProgressGump( mobile.CurrentQuest ) );
					}
				}
				else if( quest is BlackMatriarchQuest4 )
				{
					if( quest.Completed )
					{
						mobile.PlaySound( 602 );
						mobile.SendGump( new FinishQuestGump( quest ) );
						mobile.CurrentQuest = new BlackMatriarchQuest5( mobile );
						mobile.SendGump( new QuestLogUpdated() );			
					}
					else
					{
						mobile.PlaySound( 599 );
						mobile.SendGump( new QuestInProgressGump( mobile.CurrentQuest ) );
					}
				}
				else if( quest is BlackMatriarchQuest5 )
				{
					mobile.PlaySound( 599 );
					mobile.SendGump( new QuestInProgressGump( mobile.CurrentQuest ) );
				}
				else if( quest == null && mobile.SolenFriendship == SolenFriend.Black && mobile.CanStartNewQuest )
				{
					if( !mobile.HasGump( typeof( OfferQuestGump ) ) )
					{
						mobile.CurrentQuest = new BlackMatriarchQuest3( mobile );
						mobile.SendGump( new OfferQuestGump( mobile.CurrentQuest ) );
					}
				}
				else if( quest == null && mobile.SolenFriendship == SolenFriend.Black && !( mobile.CanStartNewQuest ) )
				{
					mobile.SendGump( new RestingQuestGump() );
				}
			}
		}		

		public override bool OnDragDrop( Mobile from, Item dropped )
		{
			Mobile m = from; 

			if( m != null )
			{
				PlayerMobile mobile = m as PlayerMobile;
				BaseQuest quest = mobile.CurrentQuest;

				if ( ( dropped is Seed ) )
				{
					dropped.Delete();

					if( mobile.CurrentQuest == null )
					{
						if( mobile.CanStartNewQuest )
						{
							if( mobile.SolenFriendship != SolenFriend.Black )
							{
								if( !mobile.HasGump( typeof( OfferQuestGump ) ) )
								{
									mobile.CurrentQuest = new BlackMatriarchQuest1( mobile );
									mobile.SendGump( new OfferQuestGump( mobile.CurrentQuest ) );
									return true;
								}
								return false;
							}
							else if( mobile.SolenFriendship == SolenFriend.Black ) 
							{
								this.SayTo( mobile, 1054080 );
								if( !mobile.HasGump( typeof( OfferQuestGump ) ) )
								{
									mobile.CurrentQuest = new BlackMatriarchQuest3( mobile );
									mobile.SendGump( new OfferQuestGump( mobile.CurrentQuest ) );
									return true;
								}
								return false;
							}
						}
						else
						{
							mobile.SendGump( new RestingQuestGump() );
							return false;
						}
					}
					else if( quest != null )
					{
						if( quest is BlackMatriarchQuest1  || quest is BlackMatriarchQuest2 ||
							quest is BlackMatriarchQuest3 || quest is BlackMatriarchQuest4 ||
							quest is BlackMatriarchQuest5 )
						{
							if( quest is BlackMatriarchQuest1 )
							{
								if( quest.Completed )
								{
									mobile.PlaySound( 602 );
									mobile.SendGump( new FinishQuestGump( quest ) );
									mobile.CurrentQuest = new BlackMatriarchQuest2( mobile );
									mobile.SendGump( new QuestLogUpdated() );
									return true;
								}
								else
								{
									mobile.PlaySound( 599 );
									mobile.SendGump( new QuestInProgressGump( mobile.CurrentQuest ) );
								}						
							}
							else if( quest is BlackMatriarchQuest2 )
							{
								if( quest.Completed )
								{
									mobile.PlaySound( 602 );
									mobile.SendGump( new FinishQuestGump( quest ) );
									mobile.CurrentQuest = new BlackMatriarchQuest5( mobile );
									mobile.SendGump( new QuestLogUpdated() );
									mobile.SolenFriendship = SolenFriend.Black;				
								}
								else
								{
									mobile.PlaySound( 599 );
									mobile.SendGump( new QuestInProgressGump( mobile.CurrentQuest ) );
								}
							}
							else if( quest is BlackMatriarchQuest3 )
							{
								if( quest.Completed )
								{
									mobile.PlaySound( 602 );
									mobile.SendGump( new FinishQuestGump( quest ) );
									mobile.CurrentQuest = new BlackMatriarchQuest4( mobile );
									mobile.SendGump( new QuestLogUpdated() );			
								}
								else
								{
									mobile.PlaySound( 599 );
									mobile.SendGump( new QuestInProgressGump( mobile.CurrentQuest ) );
								}
							}
							else if( quest is BlackMatriarchQuest4 )
							{
								if( quest.Completed )
								{
									mobile.PlaySound( 602 );
									mobile.SendGump( new FinishQuestGump( quest ) );
									mobile.CurrentQuest = new BlackMatriarchQuest5( mobile );
									mobile.SendGump( new QuestLogUpdated() );			
								}
								else
								{
									mobile.PlaySound( 599 );
									mobile.SendGump( new QuestInProgressGump( mobile.CurrentQuest ) );
								}
							}
							else if( quest is BlackMatriarchQuest5 )
							{
								mobile.PlaySound( 599 );
								mobile.SendGump( new QuestInProgressGump( mobile.CurrentQuest ) );
							}
							return true;
						}
						else
						{
							if( mobile.SolenFriendship == SolenFriend.Black )
							{
								mobile.PlaySound( 599 );
								mobile.SendGump( new OccupiedQuestGump( 1054081 ) );
								return true;
							}
							else
							{
								mobile.PlaySound( 599 );
								mobile.SendGump( new OccupiedQuestGump( 1054079 ) );
								return true;
							}
						}
					}
				}
				else if ( quest is BlackMatriarchQuest5 && dropped is ZoogiFungus)
				{
					if(dropped.Amount<=200)
					{
						Bag bag = new Bag();
						bag.Hue = 347;
						bag.DropItem( new TranslocationPowder(dropped.Amount/2) );
						bag.DropItem( new Gold(2000) );
						
						if( quest.CanRecieveItem( mobile, bag ) )
						{
							mobile.SendLocalizedMessage(1054100);
							mobile.SendLocalizedMessage(1054076);
							dropped.Delete();
							mobile.PlaySound( 602 );
							mobile.SendGump( new FinishQuestGump( quest ) );
							return true;
						}
						else
						{
							mobile.SendGump( new OverLoadedGump( quest ) );
							return false;
						}
					}
					else if(dropped.Amount>200)
					{
						Bag bag = new Bag();
						bag.Hue = 347;
						bag.DropItem( new TranslocationPowder(100) );
						bag.DropItem( new Gold(2000) );						
						ZoogiFungus zoogi= new ZoogiFungus();
						zoogi.Amount=dropped.Amount-200;
						bag.DropItem( zoogi );

						if( quest.CanRecieveItem( mobile, bag ) )
						{
							mobile.SendLocalizedMessage(1054100);
							mobile.SendLocalizedMessage(1054076);
							dropped.Delete();
							mobile.PlaySound( 602 );
							mobile.SendGump( new FinishQuestGump( quest ) );
							return true;
						}
						else
						{
							mobile.SendGump( new OverLoadedGump( quest ) );
							return false;
						}
					}
				}
				else if ( dropped is ZoogiFungus)
				{
					this.SayTo( mobile, 1054080 );
					return false;
				}
				else
				{
					this.SayTo( mobile, 1014123 );
				}
			}
			return false;
		} 

		public override int GetAngerSound()
		{
			return 0x259;
		}

		public override int GetIdleSound()
		{
			return 0x259;
		}

		public override int GetAttackSound()
		{
			return 0x195;
		}

		public override int GetHurtSound()
		{
			return 0x250;
		}

		public override int GetDeathSound()
		{
			return 0x25B;
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
		}
	}
}