using System;
using System.Collections;
using Server.Items;
using Server.Mobiles;
using Server.Misc;
using Server.Targeting;
using Server.Gumps;

namespace Server.Mobiles
{
	[CorpseName( "a solen infiltrator corpse" )] // TODO: Corpse name?
	public class RedSolenInfiltratorQueen : BaseCreature
	{
		[Constructable]
		public RedSolenInfiltratorQueen() : base( AIType.AI_Melee, FightMode.Closest, 10, 1, 0.2, 0.4 )
		{
			Name = "a red solen infiltrator";
			Body = 783;
			BaseSoundID = 959;

			SetStr( 326, 350 );
			SetDex( 141, 165 );
			SetInt( 96, 120 );

			SetHits( 151, 162 );

			SetDamage( 10, 15 );

			SetDamageType( ResistanceType.Physical, 70 );
			SetDamageType( ResistanceType.Poison, 30 );

			SetResistance( ResistanceType.Physical, 30, 40 );
			SetResistance( ResistanceType.Fire, 30, 35 );
			SetResistance( ResistanceType.Cold, 25, 35 );
			SetResistance( ResistanceType.Poison, 35, 40 );
			SetResistance( ResistanceType.Energy, 25, 30 );

			SetSkill( SkillName.MagicResist, 90.0 );
			SetSkill( SkillName.Tactics, 90.0 );
			SetSkill( SkillName.Wrestling, 90.0 );

			Fame = 6500;
			Karma = -6500;

			VirtualArmor = 50;

			SolenHelper.PackPicnicBasket( this );
			
			int zoogicount = Utility.RandomMinMax( 4, 16 );
			ZoogiFungus zoogi= new ZoogiFungus();
			zoogi.Amount=zoogicount;
			PackItem( zoogi );
		}
		
		public override void GenerateLoot()
		{
			AddLoot( LootPack.AosRich, 1 );
		}		

		public override bool IsEnemy( Mobile m )
		{
			PlayerMobile mobile = m as PlayerMobile; 
			
			if ( m is BlackSolenWorker || m is BlackSolenQueen || m is BlackSolenWarrior || m is BlackSolenInfiltratorQueen || m is BlackSolenInfiltratorWarrior )
				return true;
		
			if ( mobile != null )
			{
				if( mobile.SolenFriendship == SolenFriend.Red )
					return false;
			}
			return base.IsEnemy( m );
		}

		public override void OnDamage( int amount, Mobile attacker, bool willKill )
		{
			if( attacker is PlayerMobile )
			{
				PlayerMobile mobile = attacker as PlayerMobile;

				if( mobile.SolenFriendship == SolenFriend.Red )
				{
					mobile.SolenFriendship = SolenFriend.None;
					mobile.SendLocalizedMessage( 1054103 );
				}
			}
			base.OnDamage( amount, attacker, willKill );
		}

		public void GiveKillCount()
		{
			ArrayList toGive = new ArrayList();

			ArrayList list = Aggressors;
			for ( int i = 0; i < list.Count; ++i )
			{
				AggressorInfo info = (AggressorInfo)list[i];

				if ( info.Attacker.Player &&  (DateTime.Now - info.LastCombatTime) < TimeSpan.FromSeconds( 30.0 ) && !toGive.Contains( info.Attacker ) )
					toGive.Add( info.Attacker );
			}

			list = Aggressed;
			for ( int i = 0; i < list.Count; ++i )
			{
				AggressorInfo info = (AggressorInfo)list[i];

				if ( info.Defender.Player &&  (DateTime.Now - info.LastCombatTime) < TimeSpan.FromSeconds( 30.0 ) && !toGive.Contains( info.Defender ) )
					toGive.Add( info.Defender );
			}

			if ( toGive.Count == 0 )
				return;

			for ( int i = 0; i < toGive.Count; ++i )
			{
				Mobile m = (Mobile)toGive[i % toGive.Count];

				if( !(m is PlayerMobile) )
					return;

				PlayerMobile mobile = m as PlayerMobile;

				if( mobile.CurrentQuest == null )
					return;

				BaseQuest quest = mobile.CurrentQuest;
				int m_Number = quest.CompletedObjectives;
			
				if ( mobile != null ) 
				{ 
					if ( quest is BlackMatriarchQuest1 || quest is BlackMatriarchQuest3 )
					{
						if( m_Number == 7 )
							return;

						( (QuestObjective) quest.Objectives[ m_Number ] ).Completed = true;
						
						if( quest.Completed )
						{
							mobile.SendGump( new QuestLogUpdated() );
						}
					}
					return;
				}
				return;
			}
		}

		public override bool OnBeforeDeath()
		{
			if ( !NoKillAwards )
			{
				GiveKillCount();
			}
				
			return base.OnBeforeDeath();
		}

		public override int GetAngerSound()
		{
			return 0x259;
		}

		public override int GetIdleSound()
		{
			return 0x259;
		}

		public override int GetAttackSound()
		{
			return 0x195;
		}

		public override int GetHurtSound()
		{
			return 0x250;
		}

		public override int GetDeathSound()
		{
			return 0x25B;
		}

		public RedSolenInfiltratorQueen( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
		}
	}
}