using System;
using Server.Items;
using Server.Misc;
using Server.Gumps;
using Server.ContextMenus;
using System.Collections;
using Server.Engines.Plants;

namespace Server.Mobiles
{
	public class Naturalist : BaseCreature
	{
		[Constructable]
		public Naturalist() : base(AIType.AI_Thief, FightMode.None, 10, 1, 0.8, 2.6 )
		{
			InitStats( 100, 100, 25 );

			Title = "the naturalist";
			Hue = Utility.RandomSkinHue();
			NameHue = 0x35;
			this.Body = 0x190;
			this.Name = NameList.RandomName( "male" );
			Blessed = true;
			AddItem( new FancyShirt( Utility.RandomBlueHue() ) );

			Item skirt;

			switch ( Utility.Random( 2 ) )
			{
				case 0: skirt = new Skirt(); break;
				default: case 1: skirt = new Kilt(); break;
			}

			skirt.Hue = Utility.RandomGreenHue();

			AddItem( skirt );

			AddItem( new FeatheredHat( Utility.RandomGreenHue() ) );

			Item boots;

			switch ( Utility.Random( 2 ) )
			{
				case 0: boots = new Boots(); break;
				default: case 1: boots = new ThighBoots(); break;
			}

			AddItem( boots );

			Item hair = new Item( Utility.RandomList( 0x203B, 0x2049, 0x2048, 0x204A ) );

			hair.Hue = Utility.RandomNondyedHue();
			hair.Layer = Layer.Hair;
			hair.Movable = false;

			AddItem( hair );
		}

		public Naturalist( Serial serial ) : base( serial )
		{
		}

	    public override void GetContextMenuEntries( Mobile from, ArrayList list ) 
	    { 
	            base.GetContextMenuEntries( from, list ); 
        	    list.Add( new NaturalistEntry( from ) ); 
	    } 

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );

			writer.Write( (int) 0 ); // version
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );

			int version = reader.ReadInt();
		}

		public class NaturalistEntry : ContextMenuEntry
		{
			private Mobile m_Mobile;

			public NaturalistEntry( Mobile from ) : base( 6146, 3 )
			{
				m_Mobile = from;
			}
          
			public override void OnClick()
			{
				if( !( m_Mobile is PlayerMobile ) )
					return;

				PlayerMobile mobile = (PlayerMobile) m_Mobile;

				// Offer quest
				if( mobile.CurrentQuest == null )
				{
					if( mobile.CanStartNewQuest )
					{
						if ( !mobile.HasGump( typeof( OfferQuestGump ) ) )
						{
							mobile.CurrentQuest = new SolenHiveStudyQuest( mobile );
							mobile.SendGump( new OfferQuestGump( mobile.CurrentQuest ) );
						}
					}
					else
					{
						mobile.SendGump( new RestingQuestGump() );
					}
				}
					// Doing the quest
				else if( mobile.CurrentQuest is SolenHiveStudyQuest )
				{
					SolenHiveStudyQuest quest = (SolenHiveStudyQuest) mobile.CurrentQuest;

					// Finish quest
					if( quest.Completed )
					{
						mobile.PlaySound( 1075 ); // Ohh
						mobile.PlaySound( 1051 ); // Aplausos

						if( quest.StudiedOddNest )
						{	
							if( quest.CanRecieveItem( mobile, new Seed( PlantTypeInfo.RandomFirstGeneration(), PlantHue.FireRed, false ) ) )
								mobile.SendGump( new FinishQuestGump( quest, 1054051 ) );
							else
								mobile.SendGump( new OverLoadedGump( quest ) );
						}
						else
						{
							if( quest.CanRecieveItem( mobile, new Seed( PlantTypeInfo.RandomFirstGeneration(), PlantHueInfo.RandomRare(), false ) ) )
								mobile.SendGump( new FinishQuestGump( quest ) );
							else
								mobile.SendGump( new OverLoadedGump( quest ) );
						}
					}
						// Still in progress
					else
					{
						mobile.PlaySound( Utility.RandomList( 1055, 1068 ) );
						mobile.SendGump( new QuestInProgressGump( mobile.CurrentQuest ) );
					}
				}
					// Doing another quest
				else
				{
					mobile.SendGump( new OccupiedQuestGump( 1054052 ) );
				}
			}
		}
	}
}
