using Server;
using System;
using System.Collections;
using Server.Misc;
using Server.Mobiles;
using Server.Gumps;

namespace Server.Regions
{
	public class SolenHiveStudyRegion : Region
	{
		private NestStudyTimer m_NestStudyTimer;

		public static void Initialize()
		{
			Region.AddRegion( new SolenHiveStudyRegion( 0 ) );
			Region.AddRegion( new SolenHiveStudyRegion( 1 ) );
			Region.AddRegion( new SolenHiveStudyRegion( 2 ) );
			Region.AddRegion( new SolenHiveStudyRegion( 3 ) );
			Region.AddRegion( new SolenHiveStudyRegion( 4 ) );
		}

		private int m_Number;

		public SolenHiveStudyRegion( int number ) : base( "", "Solen Hive Nest " + ( number + 1 ), Map.Felucca )
		{
			m_Number = number;

			Priority = Region.HighestPriority;
			LoadFromXml = false;
			
			switch( number )
			{
					// 1st nest
				case( 0 ):
				{
					this.Coords = new ArrayList( 2 );
					this.Coords.Add( new Rectangle2D( 5905, 1908, 0, 0 ) );
					this.Coords.Add( new Rectangle2D( 5905, 1908, 22, 37 ) );
					break;
				}
					// 2nd nest
				case( 1 ):
				{
					this.Coords = new ArrayList( 2 );
					this.Coords.Add( new Rectangle2D( 5864, 1782, 0, 0 ) );
					this.Coords.Add( new Rectangle2D( 5864, 1782, 25, 32 ) );
					break;
				}
					// 3st nest
				case( 2 ):
				{
					this.Coords = new ArrayList( 4 );
					this.Coords.Add( new Rectangle2D( 5733, 1787, 0, 0 ) );
					this.Coords.Add( new Rectangle2D( 5733, 1787, 16, 15 ) );
					this.Coords.Add( new Rectangle2D( 5733, 1803, 20, 30 ) );
					this.Coords.Add( new Rectangle2D( 5738, 1832, 11, 6 ) );
					break;
				}
					// 4th nest
				case( 3 ):
				{
					this.Coords = new ArrayList( 3 );
					this.Coords.Add( new Rectangle2D( 5720, 1926, 0, 0 ) );
					this.Coords.Add( new Rectangle2D( 5720, 1926, 20, 21 ) );
					this.Coords.Add( new Rectangle2D( 5734, 1933, 20, 24 ) );
					break;
				}
					// Odd nest
				case( 4 ):
				{
					this.Coords = new ArrayList( 2 );
					this.Coords.Add( new Rectangle2D( 5653, 1857, 0, 0 ) );
					this.Coords.Add( new Rectangle2D( 5653, 1857, 23, 20 ) );
					break;
				}
			}
		}
		
		public override bool AllowHousing( Mobile from, Point3D p )
		{
			return false;
		}

		public override void OnEnter( Mobile m )
		{
			if( m == null || m.Deleted )
				return;

			if( m.Player && m is PlayerMobile && m.Alive )
			{
				PlayerMobile mobile = (PlayerMobile) m;

				if( mobile.CurrentQuest == null )
					return;

				if( mobile.CurrentQuest is SolenHiveStudyQuest )
				{
					SolenHiveStudyQuest quest = (SolenHiveStudyQuest) mobile.CurrentQuest;

					if( m_Number > ( quest.Objectives.Count - 1 ) || m_Number < 0 )
						return;
					
					if( ( (QuestObjective) quest.Objectives[ m_Number ] ).Completed )
						mobile.SendLocalizedMessage( 1054047 ); // You glance at the Egg Nest, realizing you've already studied this one.
						// Start
					else
					{
						if( m.Female )
							m.PlaySound( 778 );
						else
							m.PlaySound( 1049 );
						m.SendLocalizedMessage( 1054045 ); // You begin studying the Solen Egg Nest to gather information.

						m_NestStudyTimer = new NestStudyTimer( quest, m_Number );
						m_NestStudyTimer.Start();
					}
				}
			}
		}

		public override void OnExit( Mobile m )
		{
			if( m == null || m.Deleted )
				return;

			if( m.Player && m is PlayerMobile && m.Alive )
			{
				PlayerMobile mobile = (PlayerMobile) m;

				if( mobile.CurrentQuest == null )
					return;

				if( mobile.CurrentQuest is SolenHiveStudyQuest )
				{
					SolenHiveStudyQuest quest = (SolenHiveStudyQuest) mobile.CurrentQuest;

					if ( m_NestStudyTimer != null && m_NestStudyTimer.Running )
					{
						m.SendLocalizedMessage( 1054046 ); // You abandon your study of the Solen Egg Nest without gathering the needed information.
						m_NestStudyTimer.Stop();
					}
				}
			}
		}

		private class NestStudyTimer : Timer
		{
			private int m_Count;
			private int m_Number;
			private SolenHiveStudyQuest m_Quest;

			public NestStudyTimer( SolenHiveStudyQuest quest, int number ) : base( TimeSpan.FromSeconds( 1.0 ), TimeSpan.FromSeconds( 1.0 ) )
			{
				m_Count = 30;
				m_Number = number;
				m_Quest = quest;
			}

			protected override void OnTick()
			{
				if( m_Quest == null )
				{
					Stop();
					return;
				}

				if( m_Quest.Player == null || m_Quest.Player.Deleted )
				{
					Stop();
					return;
				}

				if( !m_Quest.Player.Alive || m_Quest.Player.Hidden )
				{
					Stop();
					return;
				}

				m_Count--;

				if( m_Count == 15 )
				{
					m_Quest.Player.PlaySound( 0x249 );

					if( m_Number == 4 )
						m_Quest.Player.SendLocalizedMessage( 1054056 );	// You notice something very odd about this Solen Egg Nest...
					else
						m_Quest.Player.SendLocalizedMessage( 1054058 ); // You begin recording your completed notes on a bit of parchment.
				}
				if( m_Count == 0 )
				{
					if( m_Number == 4 )
					{
						m_Quest.Player.SendLocalizedMessage( 1054057 );	// You complete your examination of this bizarre Egg Nest...
						m_Quest.StudiedOddNest = true;
					}
					else
						m_Quest.Player.SendLocalizedMessage( 1054054 ); // You have completed your study of this Solen Egg Nest. You put your notes away.
	
					( (QuestObjective) m_Quest.Objectives[ m_Number ] ).Completed = true;

					if( m_Quest.Completed )
						m_Quest.Player.SendGump( new QuestLogUpdated() );

					Stop();
				}
			}
		}
	}
}